Court of Criminal Appeals Opinions | Tennessee Administrative Office of the Courts

# Tennessee Administrative Office of the Courts

### SEARCH TNCOURTS.GOV:

Search this site:
Administrative Office of the Courts
511 Union Street, Suite 600
Nashville, TN 37219
(615) 741-2687
(800) 448-7970

© 2013 Tennessee Courts System

## Court of Criminal Appeals Opinions

Court
County
Authoring Judge
Originating Judge
Date Filter
Format: 08/30/2013
And:
Format: 08/30/2013
Case Number
Case Name
keyword search
Sort by:
Order:

Jerry Whiteside Dickerson v. David Sexton, Warden E2013-00993-CCA-R3-HC Authoring Judge: Presiding Judge Joseph M. Tipton Trial Court Judge: Judge Lynn w. Brown The Petitioner, Jerry Whiteside Dickerson, appeals the Johnson County Criminal Court’s summary dismissal of his petition for the writ of habeas corpus regarding his convictions for first degree felony murder and especially aggravated robbery, for which he is serving an effective life sentence. The Petitioner contends that the trial court erred in dismissing the petition. We affirm the judgment of the trial court. | Johnson County | Court of Criminal Appeals | 08/30/13 |  |
Gary Thomas Reed v. State of Tennessee E2013-00169-CCA-R3-PC Authoring Judge: Judge Robert W. Wedemeyer Trial Court Judge: Judge Leon C. Burns, Jr. A Cumberland County jury convicted the Petitioner, Gary Thomas Reed, of initiating the process of manufacturing methamphetamine. This Court affirmed the Petitioner’s conviction and sentence on appeal. State v. Gary Thomas Reed, No. E2009-02238-CCA-R3-CD, 2011 WL 1842711 (Tenn. Crim. App., at Knoxville, Aug. 24, 2011), perm. app. denied (Tenn. Aug. 24, 2011). The Petitioner timely filed a petition for post-conviction relief claiming that he had received the ineffective assistance of counsel. The post-conviction court denied relief after a hearing. On appeal, the Petitioner claims that his attorney failed to call an exculpatory witness at trial and failed to object to a violation of the sequestration rule. After a thorough review of the record, the briefs, and relevant authorities, we affirm the post-conviction court’s judgment. | Cumberland County | Court of Criminal Appeals | 08/30/13 |  |
State of Tennessee v. Stanley B.Hill E2012-00289-CCA-R3-CD Authoring Judge: Judge Alan E. Glenn Trial Court Judge: Judge Michael H. Meares The defendant, Stanley B. Hill, was convicted by a Blount County jury of the first degree premeditated murder of his wife, Vickie Hill, and sentenced to life imprisonment. On appeal, he argues that the trial court committed reversible error by: (1) allowing the medical examiner to use demonstrative evidence that was inherently unreliable, unfairly prejudicial, cumulative, and not disclosed to defense counsel prior to trial and (2) excluding a piece of physical evidence as a sanction for his violation of the reciprocal discovery obligations under Rule 16 of the Tennessee Rules of Criminal Procedure. Following our review, we affirm the judgment of the trial court. | Blount County | Court of Criminal Appeals | 08/30/13 |  |
State of Tennessee v. Troy Reynolds E2012-02588-CCA-R3-CD Authoring Judge: Judge Jeffrey S. Bivins Trial Court Judge: Judge David R. Duggan Troy Reynolds (“the Defendant”) pleaded guilty in February 2012 to evading arrest by vehicle, theft of property valued at over $1,000, and burglary. Pursuant to a plea agreement, he was sentenced as a Range I standard offender to an effective sentence of three years to be suspended and served on supervised probation, consecutive to an earlier suspended sentence. The State later filed a violation of probation warrant. The Defendant was taken into custody, and a probation revocation hearing was held. At the conclusion of the hearing, the trial court revoked the Defendant’s probation and ordered him to serve the remainder of his sentence in confinement. The Defendant appealed the trial court’s ruling. Upon our thorough review of the record and applicable law, we affirm the trial court’s judgment. | Blount County | Court of Criminal Appeals | 08/30/13 |  |
State of Tennessee v. Clifford Deleon Thomas E2012-01956-CCA-R3-CD Authoring Judge: Judge John Everett Williams Trial Court Judge: Judge Stephen W. Sword Defendant pled guilty to one count of possession of more than 0.5 grams of cocaine with intent to sell, a Class B felony, and one count of driving with a suspended license, a Class B misdemeanor, while reserving a certified question of law concerning the constitutionality of a city ordinance requiring vehicles operating within the municipality to have a “tag light” illuminating the vehicle’s license plate after dark. The defendant was sentenced to eight years probation on the possession charge and to a concurrent six months probation for driving with a suspended license. Upon review, we conclude that the certified question reserved by the defendant is not dispositive of the constitutionality of the traffic stop at issue. The defendant’s appeal is dismissed accordingly. | Knox County | Court of Criminal Appeals | 08/30/13 |  |
State of Tennessee v. Carlos Smith W2012-01931-CCA-R3-CD Authoring Judge: Judge James Curwood Witt Jr. Trial Court Judge: Judge James C. Beasley Jr. The defendant, Carlos Smith, appeals his Shelby County Criminal Court jury convictions of two counts of attempted second degree murder, two counts of aggravated assault, and one count each of aggravated robbery, especially aggravated burglary, employing a firearm during a dangerous offense, and being a convicted felon in possession of a handgun, claiming that the trial court erred by denying his motion to sever offenses and that the State violated the tenets of Brady v. Maryland, 373 U.S. 83 (1963). Discerning no error, we affirm. | Shelby County | Court of Criminal Appeals | 08/29/13 |  |
State of Tennessee v. Stanley Abernathy James E2012-01912-CCA-R3-CD Authoring Judge: Presiding Judge Joseph M. Tipton Trial Court Judge: Judge Mary Beth Leibowitz The Defendant, Stanley Abernathy James, was convicted by a Knox County Criminal Court jury of second degree murder, a Class A felony, for which he is serving a twenty-five-year sentence. In this appeal, the Defendant contends that the evidence is insufficient to support his conviction. We affirm the judgment of the trial court. | Knox County | Court of Criminal Appeals | 08/29/13 |  |
State of Tennessee v. Josh L. Bowman - dissenting opinion E2012-00923-CCA-R3-CD Authoring Judge: Judge Thomas T. Woodall Trial Court Judge: Judge Jon Kerry Blackwood I concur in that portion of the majority opinion which holds the trial court did not err by denying the appellant’s motion to suppress his statement. I disagree with the remaining parts of the opinion and therefore would affirm all the judgments of the trial court. | Knox County | Court of Criminal Appeals | 08/29/13 |  |
State of Tennessee v. Josh L. Bowman E2012-00923-CCA-R3-CD Authoring Judge: Judge Norma McGee Ogle Trial Court Judge: Judge Jon Kerry Blackwood A Knox County Criminal Court Jury convicted the appellant, Josh L. Bowman, of three counts of first degree felony murder, one count of especially aggravated kidnapping, one count of especially aggravated robbery, two counts of aggravated burglary, and one count of employing a firearm during the commission of a dangerous felony. After the jury announced its verdicts, the appellant pled guilty to one count of employing a firearm during the commission of a dangerous felony when, at the time of the offense, the appellant had a prior felony conviction. The trial court merged the murder convictions, merged the burglary convictions, merged the employing a firearm convictions, and sentenced the appellant to an effective sentence of life plus sixty years in confinement. On appeal, the appellant contends that the trial court erred by failing to suppress his statement to police, by allowing the State to show a transcript of his statement simultaneously with his video-recorded statement, and by failing to instruct the jury as provided by State v. White, 362 S.W.3d 559 (Tenn. 2012). Based upon the oral arguments, the record, and the parties’ briefs, we conclude that the trial court’s failing to instruct the jury properly pursuant to White constitutes reversible error. Therefore, the appellant’s conviction for especially aggravated kidnapping must be reversed and the case remanded to the trial court for a new trial as to that offense. | Hickman County, Houston County | Court of Criminal Appeals | 08/29/13 |  |
State of Tennessee v. Lamar Parrish Carter - Concurring M2012-01734-CCA-R9-CD Authoring Judge: Judge Thomas T. Woodall Trial Court Judge: Judge Seth Norman In this case, Defendant filed a motion to dismiss the indictment pursuant to the constitutional protections afforded him to be protected from double jeopardy. Defendant asserts in this interlocutory appeal that the trial court erred by denying the motion. I concur in the results reached by the majority, but write separately to express my opinion that the only justifiable reason for the trial court to deny the motion was the Defendant’s failure to explicitly object to the declaration of a mistrial. | Davidson County | Court of Criminal Appeals | 08/29/13 |  |
State of Tennessee v. Lamar Parrish Carter M2012-01734-CCA-R9-CD Authoring Judge: Judge Robert W. Wedemeyer Trial Court Judge: Judge Seth Norman This is an interlocutory appeal, pursuant to Tennessee Rule of Appellate Procedure 9, from the trial court’s grant of a mistrial based upon a “manifest necessity.” The Defendant, Lamar Parrish Carter, appeals the trial court’s ruling, arguing that his attorney’s cross-examination of a co-defendant about her range of punishment, which was also the range of punishment for the Defendant, was not improper and did not warrant a mistrial. After a thorough review of the record and the relevant law, we affirm the trial court’s judgment. | Davidson County | Court of Criminal Appeals | 08/29/13 |  |
State of Tennessee v. Amber R. Galemore M2012-01783-CCA-R3-CD Authoring Judge: Judge Robert W. Wedemeyer Trial Court Judge: Judge John H. Gasaway In two separate cases, the Defendant, Amber R. Galemore, pled guilty to possession with intent to sell or deliver cocaine and to theft of property. She was sentenced to an effective sentence of eight years on probation. As part of the Defendant’s plea agreement, she reserved a certified question of law pursuant to Tennessee Rule of Criminal Procedure 37(b)(2). The question is articulated in the record as, “Whether the search warrant issued by a General Sessions Judge for Montgomery County, Tennessee, which was based on statements of an unknown person outside the defendant’s residence and computer keystroke software results[,] provided a sufficient nexus to make a probable cause determination.” After reviewing the record and applicable law, we conclude that the trial court did not err when it denied the Defendant’s motion to suppress. Accordingly, we affirm the Defendant’s convictions. | Montgomery County | Court of Criminal Appeals | 08/29/13 |  |
In the Matter of Lakita E. P. and Michael A. P. M2013-00384-COA-R3-PT Authoring Judge: Judge Richard H. Dinkins Trial Court Judge: Judge Jimmy White A father’s parental rights to his two children were terminated on the grounds of abandonment by engaging in conduct exhibiting a wanton disregard for the welfare of the children, non-compliance with the permanency plan, and severe child abuse against children who resided with Father. He appeals, contending that the Department of Children’s Services failed to expend reasonable efforts to reunite him with the children and that termination of his rights was not in the children’s best interest. Finding no error, we affirm the judgment of the trial court. | Clay County | Court of Criminal Appeals | 08/28/13 |  |

- 1
- 2
- 3
- 4
- 5
- 6
- 7
- 8
- 9
- …
- next ›
- last »